@@ -28,6 +28,8 @@
 build <- function(pkg = ".", path = NULL, binary = FALSE, vignettes = TRUE,
                   args = NULL, quiet = FALSE) {
   pkg <- as.package(pkg)
+  check_build_tools(pkg)
+
   if (is.null(path)) {
     path <- dirname(pkg$path)
   }
@@ -51,7 +53,14 @@ build <- function(pkg = ".", path = NULL, binary = FALSE, vignettes = TRUE,
 
     ext <- "tar.gz"
   }
-  with_libpaths(c(tempdir(), .libPaths()), R(cmd, path, quiet = quiet))
+
+  # Create temporary library to ensure that default library doesn't get
+  # contaminated
+  temp_lib <- tempfile()
+  dir.create(temp_lib)
+  on.exit(unlink(temp_lib, recursive = TRUE), add = TRUE)
+
+  with_libpaths(c(temp_lib, .libPaths()), R(cmd, path, quiet = quiet))
   targz <- paste0(pkg$package, "_", pkg$version, ".", ext)
 
   file.path(path, targz)
@@ -74,7 +83,6 @@ build <- function(pkg = ".", path = NULL, binary = FALSE, vignettes = TRUE,
 #'   which version of R is used to build the package. Possible options are
 #'   listed on \url{http://win-builder.r-project.org/}. Defaults to the
 #'   released version of R.
-#' @importFrom RCurl ftpUpload
 #' @export
 #' @family build functions
 build_win <- function(pkg = ".", version = c("R-release", "R-devel"),
@@ -94,7 +102,7 @@ build_win <- function(pkg = ".", version = c("R-release", "R-devel"),
 
   url <- paste0("ftp://win-builder.r-project.org/", version, "/",
                 basename(built_path))
-  lapply(url, ftpUpload, what = built_path)
+  lapply(url, RCurl::ftpUpload, what = built_path)
 
   if (!quiet) {
     message("Check your email for a link to the built package",
