@@ -28,7 +28,7 @@
 run_examples <- function(pkg = ".", start = NULL, show = TRUE, test = FALSE,
                          run = TRUE, fresh = FALSE) {
   pkg <- as.package(pkg)
-  document(pkg, reload = FALSE)
+  document(pkg)
 
   files <- rd_files(pkg)
 
@@ -45,18 +45,10 @@ run_examples <- function(pkg = ".", start = NULL, show = TRUE, test = FALSE,
   }
   if (length(files) == 0) return()
 
-  message("Running ", length(files), " example files in ", pkg$package)
-  rule()
+  rule("Running ", length(files), " example files in ", pkg$package)
 
   if (fresh) {
-    to_run <- bquote({
-      require("devtools", quiet = TRUE)
-      load_all(.(pkg$path), export_all = FALSE, quiet = TRUE)
-
-      lapply(.(files), devtools:::run_example,
-        show = .(show), test = .(test), run = .(run))
-      invisible()
-    })
+    to_run <- substitute(devtools::run_examples(path), list(path = pkg$path))
     eval_clean(to_run)
   } else {
     load_all(pkg, reset = TRUE, export_all = FALSE)
