@@ -12,16 +12,14 @@
 #' @seealso \code{\link{clean_vignettes}} to remove the pdfs in
 #'   \file{inst/doc} created from vignettes
 #' @export
-#' @importFrom tools buildVignettes
-#' @importFrom utils Sweave
 #' @seealso \code{\link{clean_vignettes}} to remove build tex/pdf files.
 build_vignettes <- function(pkg = ".") {
   pkg <- as.package(pkg)
-  vigns <- pkgVignettes(dir = pkg$path)
+  vigns <- tools::pkgVignettes(dir = pkg$path)
   if (length(vigns$doc) == 0) return()
 
   message("Building ", pkg$package, " vignettes")
-  buildVignettes(dir = pkg$path, tangle = TRUE)
+  tools::buildVignettes(dir = pkg$path, tangle = TRUE)
   copy_vignettes(pkg)
 
   invisible(TRUE)
@@ -37,7 +35,7 @@ build_vignettes <- function(pkg = ".") {
 #' @export
 clean_vignettes <- function(pkg = ".") {
   pkg <- as.package(pkg)
-  vigns <- pkgVignettes(dir = pkg$path)
+  vigns <- tools::pkgVignettes(dir = pkg$path)
   if (basename(vigns$dir) != "vignettes") return()
 
   message("Cleaning built vignettes from ", pkg$package)
@@ -63,8 +61,7 @@ ext_variations <- function(path, valid_ext) {
   unique(c(outer(file_name(path), valid_ext, FUN = paste, sep = ".")))
 }
 
-#' @importFrom tools file_path_sans_ext
 file_name <- function(x) {
   if (length(x) == 0) return(NULL)
-  file_path_sans_ext(basename(x))
+  tools::file_path_sans_ext(basename(x))
 }
